@@ -10,10 +10,10 @@
  * Copyright:
  * Copyright (C) 2009 Greenbone Networks GmbH
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2,
- * or, at your option, any later version as published by the Free
- * Software Foundation
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -82,274 +82,14 @@ check_is_file (const char *name)
     }
 }
 
-
-/* Modified copy of openvas-client/src/util/file_utils.c. */
-
-/**
- * @brief Recursively removes files and directories.
- *
- * This function will recursively call itself to delete a path and any
- * contents of this path.
- *
- * @param[in]  pathname  Name of file to be deleted from filesystem.
- *
- * @return 0 if the name was successfully deleted, -1 if an error occurred.
- */
-static int
-file_utils_rmdir_rf (const gchar * pathname)
-{
-  if (openvas_file_check_is_dir (pathname) == 1)
-    {
-      GError *error = NULL;
-      GDir *directory = g_dir_open (pathname, 0, &error);
-
-      if (directory == NULL)
-        {
-          if (error)
-            {
-              g_warning ("g_dir_open(%s) failed - %s\n", pathname, error->message);
-              g_error_free (error);
-            }
-          return -1;
-        }
-      else
-        {
-          int ret = 0;
-          const gchar *entry = NULL;
-
-          while ((entry = g_dir_read_name (directory)) != NULL && (ret == 0))
-            {
-              gchar *entry_path = g_build_filename (pathname, entry, NULL);
-              ret = file_utils_rmdir_rf (entry_path);
-              g_free (entry_path);
-              if (ret != 0)
-                {
-                  g_warning ("Failed to remove %s from %s!", entry, pathname);
-                  g_dir_close (directory);
-                  return ret;
-                }
-            }
-          g_dir_close (directory);
-        }
-    }
-
-  return g_remove (pathname);
-}
-
-/**
- * @brief Reads contents from a source file into a destination file.
- *
- * The source file is read into memory, so it is inefficient and likely to fail
- * for really big files.
- *
- * If the destination file does exist already, it will be overwritten.
- *
- * @param[in]  source_file  Source file name.
- * @param[in]  dest_file    Destination file name.
- *
- * @return TRUE if successful, FALSE otherwise.
- */
-static gboolean
-file_utils_copy_file (const gchar *source_file, const gchar *dest_file)
-{
-  gchar *src_file_content = NULL;
-  gsize src_file_size = 0;
-  size_t bytes_written = 0;
-  FILE *fd = NULL;
-  GError *error;
-
-  /* Read file content into memory. */
-
-  error = NULL;
-  if (g_file_get_contents (source_file,
-                           &src_file_content,
-                           &src_file_size,
-                           &error)
-      == FALSE)
-    {
-      if (error)
-        {
-          g_debug ("%s: failed to read %s: %s",
-                   __FUNCTION__, source_file, error->message);
-          g_error_free (error);
-        }
-      return FALSE;
-    }
-
-  /* Open destination file. */
-
-  fd = fopen (dest_file, "wb");
-  if (fd == NULL)
-    {
-      g_debug ("%s: failed to open %s", __FUNCTION__, dest_file);
-      g_free (src_file_content);
-      return FALSE;
-    }
-
-  /* Write content of src to dst and close it. */
-
-  bytes_written = fwrite (src_file_content, 1, (size_t) src_file_size, fd);
-  fclose (fd);
-
-  if (bytes_written != (size_t) src_file_size)
-    {
-      g_debug ("%s: failed to write to %s"
-               " (%zu/%" G_GSIZE_FORMAT ")",
-               __FUNCTION__, dest_file, bytes_written, src_file_size);
-      g_free (src_file_content);
-      return FALSE;
-    }
-  g_free (src_file_content);
-
-  return TRUE;
-}
-
-/**
- * @brief Reads contents from a source file into a destination file
- * @brief and unlinks the source file.
- *
- * The source file is read into memory, so it is inefficient and likely to fail
- * for really big files.
- *
- * If the destination file does exist already, it will be overwritten.
- *
- * @param[in]  source_file  Source file name.
- * @param[in]  dest_file    Destination file name.
- *
- * @return TRUE if successful, FALSE otherwise (displays error but does not
- *         clean up).
- */
-static gboolean
-file_utils_move_file (const gchar *source_file, const gchar *dest_file)
-{
-  /* Copy file (will displays errors itself). */
-
-  if (file_utils_copy_file (source_file, dest_file) == FALSE)
-    return FALSE;
-
-  /* Remove source file. */
-
-  if (remove (source_file) != 0)
-    {
-      g_debug ("%s: failed to remove %s", __FUNCTION__, source_file);
-      return FALSE;
-    }
-
-  return TRUE;
-}
-
 
 /* Key creation. */
 
 /**
- * @brief Create a private key for local checks.
+ * @brief Create an ssh key for local security checks.
  *
  * Forks and creates a key for local checks by calling
- * "openssl pkcs8 -topk8 -v2 des3 -in filepath -passin pass:passphrase -out
- *          filepath.p8 -passout pass:passphrase"
- * Directories within privkey_file will be created if they do not exist.
- *
- * @param[in]  pubkey_file      Path to file of public key (a .pub will be
- *                              stripped).
- * @param[in]  privkey_file     Name of private key file to be created.
- * @param[in]  passphrase_pub   The passphrase for the public key.
- * @param[in]  passphrase_priv  Passhprase for the private key.
- *
- * @return 0 if successful, -1 otherwise.
- */
-static int
-ssh_privkey_create (const char *pubkey_file, const char *privkey_file,
-                    const char *passphrase_pub, const char *passphrase_priv)
-{
-  gchar *astdout = NULL;
-  gchar *astderr = NULL;
-  GError *err = NULL;
-  gint exit_status;
-  gchar *dir = NULL;
-  gchar *pubkey_stripped = NULL;
-  gchar *command;
-
-  /* Sanity-check essential parameters. */
-  if (!passphrase_pub || !passphrase_priv)
-    {
-      g_debug ("%s: parameter error", __FUNCTION__);
-      return -1;
-    }
-
-  /* Sanity check files. */
-  if (g_file_test (pubkey_file, G_FILE_TEST_EXISTS) == FALSE)
-    {
-      g_debug ("%s: failed to find public key %s", __FUNCTION__, pubkey_file);
-      return -1;
-    }
-  if (g_file_test (privkey_file, G_FILE_TEST_EXISTS))
-    {
-      g_debug ("%s: file already exists.", __FUNCTION__);
-      return -1;
-    }
-  dir = g_path_get_dirname (privkey_file);
-  if (g_mkdir_with_parents (dir, 0755 /* "rwxr-xr-x" */ ))
-    {
-      g_debug ("%s: failed to access dir folder %s", __FUNCTION__, dir);
-      g_free (dir);
-      return -1;
-    }
-  g_free (dir);
-
-  /* Strip ".pub" off public key filename, if any. */
-
-  if (g_str_has_suffix (pubkey_file, ".pub") == TRUE)
-    {
-      pubkey_stripped = g_malloc (strlen (pubkey_file) - strlen (".pub") + 1);
-      g_strlcpy (pubkey_stripped,
-                 pubkey_file,
-                 strlen (pubkey_file) - strlen (".pub") + 1);
-    }
-  else
-    pubkey_stripped = g_strdup (pubkey_file);
-
-  /* Spawn openssl. */
-
-  command =
-    g_strconcat ("openssl pkcs8 -topk8 -v2 des3"
-                 " -in ", pubkey_stripped,
-                 " -passin pass:\"", passphrase_pub, "\"",
-                 " -out ", privkey_file,
-                 " -passout pass:\"", passphrase_priv, "\"",
-                 NULL);
-  g_debug ("command: openssl pkcs8 -topk8 -v2 des3"
-           " -in %s -passin pass:\"********\" -out %s"
-           " -passout pass:\"********\"",
-           pubkey_stripped,
-           privkey_file);
-  g_free (pubkey_stripped);
-
-  if ((g_spawn_command_line_sync (command, &astdout, &astderr, &exit_status,
-                                  &err)
-       == FALSE)
-      || (WIFEXITED (exit_status) == 0)
-      || WEXITSTATUS (exit_status))
-    {
-      g_debug ("%s: openssl failed with %d", __FUNCTION__, exit_status);
-      g_debug ("%s: stdout: %s", __FUNCTION__, astdout);
-      g_debug ("%s: stderr: %s", __FUNCTION__, astderr);
-      g_free (command);
-      g_free (astdout);
-      g_free (astderr);
-      return -1;
-    }
-
-  g_free (command);
-  g_free (astdout);
-  g_free (astderr);
-  return 0;
-}
-
-/**
- * @brief Create a public key.
- *
- * Forks and creates a key for local checks by calling
- * "ssh-keygen -t rsa -f filepath -C comment -P passhprase -q".
+ * 'ssh-keygen -t rsa -f filepath -C "comment" -P "passhprase"'.
  * A directory will be created if it does not exist.
  *
  * @param[in]  comment     Comment to use.
@@ -359,16 +99,14 @@ ssh_privkey_create (const char *pubkey_file, const char *privkey_file,
  * @return 0 if successful, -1 otherwise.
  */
 static int
-ssh_pubkey_create (const char *comment,
-                   const char *passphrase,
-                   const char *filepath)
+create_ssh_key (const char *comment, const char *passphrase,
+                const char *privpath)
 {
   gchar *astdout = NULL;
   gchar *astderr = NULL;
   GError *err = NULL;
   gint exit_status = 0;
   gchar *dir;
-  gchar *file_pubstripped;
   char *command;
 
   /* Sanity-check essential parameters. */
@@ -386,7 +124,7 @@ ssh_pubkey_create (const char *comment,
 
   /* Sanity check files. */
 
-  dir = g_path_get_dirname (filepath);
+  dir = g_path_get_dirname (privpath);
   if (g_mkdir_with_parents (dir, 0755 /* "rwxr-xr-x" */ ))
     {
       g_debug ("%s: failed to access %s", __FUNCTION__, dir);
@@ -395,29 +133,11 @@ ssh_pubkey_create (const char *comment,
     }
   g_free (dir);
 
-  /* Strip ".pub" off filename, if any. */
-
-  if (g_str_has_suffix (filepath, ".pub") == TRUE)
-    {
-      file_pubstripped = g_malloc (strlen (filepath) - strlen (".pub") + 1);
-      g_strlcpy (file_pubstripped,
-                 filepath,
-                 strlen (filepath) - strlen (".pub") + 1);
-    }
-  else
-    file_pubstripped = g_strdup (filepath);
-
   /* Spawn ssh-keygen. */
-
-  command = g_strconcat ("ssh-keygen -t rsa"
-                         " -f ", file_pubstripped,
-                         " -C \"", comment, "\""
-                         " -P \"", passphrase, "\"",
-                         NULL);
+  command = g_strconcat ("ssh-keygen -t rsa -f ", privpath, " -C \"", comment,
+                         "\" -P \"", passphrase, "\"", NULL);
   g_debug ("command: ssh-keygen -t rsa -f %s -C \"%s\" -P \"********\"",
-           file_pubstripped,
-           comment);
-  g_free (file_pubstripped);
+           privpath, comment);
 
   if ((g_spawn_command_line_sync (command, &astdout, &astderr, &exit_status,
                                   &err)
@@ -427,16 +147,14 @@ ssh_pubkey_create (const char *comment,
     {
       if (err)
         {
-          g_debug ("%s: failed to create public key: %s\n",
+          g_debug ("%s: failed to create private key: %s\n",
                    __FUNCTION__, err->message);
           g_error_free (err);
         }
       else
-        g_debug ("%s: failed to create public key\n", __FUNCTION__);
+        g_debug ("%s: failed to create private key\n", __FUNCTION__);
       g_debug ("%s: key-gen failed with %d (WIF %i, WEX %i).\n",
-               __FUNCTION__,
-               exit_status,
-               WIFEXITED (exit_status),
+               __FUNCTION__, exit_status, WIFEXITED (exit_status),
                WEXITSTATUS (exit_status));
       g_debug ("%s: stdout: %s", __FUNCTION__, astdout);
       g_debug ("%s: stderr: %s", __FUNCTION__, astderr);
@@ -454,23 +172,19 @@ ssh_pubkey_create (const char *comment,
 /**
  * @brief Create local security check (LSC) keys.
  *
- * @param[in]   name         User name.
  * @param[in]   password     Password.
- * @param[out]  public_key   Public key.
  * @param[out]  private_key  Private key.
  *
  * @return 0 success, -1 error.
  */
 int
-lsc_user_keys_create (const gchar *name,
-                      const gchar *password,
-                      gchar **public_key,
+lsc_user_keys_create (const gchar *password,
                       gchar **private_key)
 {
   GError *error;
   gsize length;
-  char key_dir[] = "/tmp/key_XXXXXX";
-  gchar *public_key_path, *private_key_path;
+  char key_dir[] = "/tmp/openvas_key_XXXXXX";
+  gchar *key_path = NULL;
   int ret = -1;
 
   /* Make a directory for the keys. */
@@ -478,57 +192,23 @@ lsc_user_keys_create (const gchar *name,
   if (mkdtemp (key_dir) == NULL)
     return -1;
 
-  /* Create public key. */
-
-  public_key_path = g_build_filename (key_dir, "key.pub", NULL);
-  if (ssh_pubkey_create ("Key generated by OpenVAS Manager",
-                         password,
-                         public_key_path))
-    {
-      g_free (public_key_path);
-      goto rm_key_exit;
-    }
-
   /* Create private key. */
-
-  private_key_path = g_build_filename (key_dir, "key.priv", NULL);
-  if (ssh_privkey_create (public_key_path,
-                          private_key_path,
-                          password,
-                          password))
+  key_path = g_build_filename (key_dir, "key", NULL);
+  if (create_ssh_key ("Key generated by OpenVAS Manager", password, key_path))
     goto free_exit;
 
-  /* Read the keys into memory. */
-
   error = NULL;
-  g_file_get_contents (public_key_path, public_key, &length, &error);
+  g_file_get_contents (key_path, private_key, &length, &error);
   if (error)
     {
       g_error_free (error);
       goto free_exit;
     }
-
-  error = NULL;
-  g_file_get_contents (private_key_path, private_key, &length, &error);
-  if (error)
-    {
-      g_error_free (error);
-      goto free_exit;
-    }
-
-  /* Return. */
-
   ret = 0;
-
  free_exit:
 
-  g_free (public_key_path);
-  g_free (private_key_path);
-
- rm_key_exit:
-
-  file_utils_rmdir_rf (key_dir);
-
+  g_free (key_path);
+  openvas_file_remove_recurse (key_dir);
   return ret;
 }
 
@@ -606,7 +286,7 @@ lsc_user_rpm_create (const gchar *username,
   g_debug ("%s: copy key to temporary directory\n", __FUNCTION__);
   pubkey_basename = g_strdup_printf ("%s.pub", username);
   new_pubkey_filename = g_build_filename (tmpdir, pubkey_basename, NULL);
-  if (file_utils_copy_file (public_key_path, new_pubkey_filename)
+  if (openvas_file_copy (public_key_path, new_pubkey_filename)
       == FALSE)
     {
       g_debug ("%s: failed to copy key file %s to %s",
@@ -676,7 +356,7 @@ lsc_user_rpm_create (const gchar *username,
 
   /* Move the RPM from the temporary directory to the given destination. */
 
-  if (file_utils_move_file (rpm_path, to_filename) == FALSE && success == TRUE)
+  if (openvas_file_move (rpm_path, to_filename) == FALSE && success == TRUE)
     {
       g_debug ("%s: failed to move RPM %s to %s",
                __FUNCTION__, rpm_path, to_filename);
@@ -685,7 +365,7 @@ lsc_user_rpm_create (const gchar *username,
 
   /* Remove the copy of the public key and the temporary directory. */
 
-  if (file_utils_rmdir_rf (tmpdir) != 0 && success == TRUE)
+  if (openvas_file_remove_recurse (tmpdir) != 0 && success == TRUE)
     {
       g_debug ("%s: failed to remove temporary directory %s",
                __FUNCTION__, tmpdir);
@@ -726,7 +406,7 @@ alien_found ()
   return found;
 }
 
-/*
+/**
  * @brief Recreate RPM package.
  *
  * @param[in]   name         User name.
@@ -792,13 +472,13 @@ lsc_user_rpm_recreate (const gchar *name, const char *public_key,
 
  rm_exit:
 
-  file_utils_rmdir_rf (rpm_dir);
+  openvas_file_remove_recurse (rpm_dir);
 
  free_exit:
 
   g_free (public_key_path);
 
-  file_utils_rmdir_rf (key_dir);
+  openvas_file_remove_recurse (key_dir);
 
   return ret;
 }
@@ -908,7 +588,7 @@ lsc_user_deb_create (const gchar *user, const gchar *rpm_file)
   return deb_name;
 }
 
-/*
+/**
  * @brief Recreate Debian package.
  *
  * @param[in]   name         User name.
@@ -970,13 +650,13 @@ lsc_user_deb_recreate (const gchar *name, const char *rpm, gsize rpm_size,
 
  rm_exit:
 
-  file_utils_rmdir_rf (deb_dir);
+  openvas_file_remove_recurse (deb_dir);
 
  free_exit:
 
   g_free (rpm_path);
 
-  file_utils_rmdir_rf (rpm_dir);
+  openvas_file_remove_recurse (rpm_dir);
 
   return ret;
 }
@@ -1185,7 +865,7 @@ lsc_user_exe_create (const gchar *user_name, const gchar *password,
   return 0;
 }
 
-/*
+/**
  * @brief Recreate NSIS package.
  *
  * @param[in]   name         User name.
@@ -1231,194 +911,9 @@ lsc_user_exe_recreate (const gchar *name, const gchar *password,
 
  rm_exit:
 
-  file_utils_rmdir_rf (exe_dir);
+  openvas_file_remove_recurse (exe_dir);
 
   g_free (exe_path);
 
   return ret;
 }
-
-
-/* Generation of all packages. */
-
-/**
- * @brief Create local security check (LSC) packages.
- *
- * @param[in]   name         User name.
- * @param[in]   password     Password.
- * @param[out]  public_key   Public key.
- * @param[out]  private_key  Private key.
- * @param[out]  rpm          RPM package.
- * @param[out]  rpm_size     Size of RPM package, in bytes.
- * @param[out]  deb          Debian package.
- * @param[out]  deb_size     Size of Debian package, in bytes.
- * @param[out]  exe          NSIS package.
- * @param[out]  exe_size     Size of NSIS package, in bytes.
- *
- * @return 0 success, -1 error.
- */
-int
-lsc_user_all_create (const gchar *name,
-                     const gchar *password,
-                     gchar **public_key,
-                     gchar **private_key,
-                     void **rpm, gsize *rpm_size,
-                     void **deb, gsize *deb_size,
-                     void **exe, gsize *exe_size)
-{
-  GError *error;
-  gsize length;
-  gchar *public_key_path, *private_key_path;
-  char rpm_dir[] = "/tmp/rpm_XXXXXX";
-  char key_dir[] = "/tmp/key_XXXXXX";
-  char exe_dir[] = "/tmp/exe_XXXXXX";
-  gchar *rpm_path, *deb_path, *exe_path;
-  int ret = -1;
-
-  if (alien_found () == FALSE)
-    return -1;
-
-  /* Make a directory for the keys. */
-
-  if (mkdtemp (key_dir) == NULL)
-    return -1;
-
-  /* Create public key. */
-
-  public_key_path = g_build_filename (key_dir, "key.pub", NULL);
-  if (ssh_pubkey_create ("Key generated by OpenVAS Manager",
-                         password,
-                         public_key_path))
-    {
-      g_free (public_key_path);
-      goto rm_key_exit;
-    }
-
-  /* Create private key. */
-
-  private_key_path = g_build_filename (key_dir, "key.priv", NULL);
-  if (ssh_privkey_create (public_key_path,
-                          private_key_path,
-                          password,
-                          password))
-    goto free_exit;
-
-  /* Create RPM package. */
-
-  if (mkdtemp (rpm_dir) == NULL)
-    goto free_exit;
-  rpm_path = g_build_filename (rpm_dir, "p.rpm", NULL);
-  g_debug ("%s: rpm_path: %s", __FUNCTION__, rpm_path);
-  if (lsc_user_rpm_create (name, public_key_path, rpm_path) == FALSE)
-    {
-      g_free (rpm_path);
-      goto rm_exit;
-    }
-
-  /* Create Debian package. */
-
-  deb_path = lsc_user_deb_create (name, rpm_path);
-  if (deb_path == NULL)
-    {
-      g_free (rpm_path);
-      g_free (deb_path);
-      goto rm_exit;
-    }
-  g_debug ("%s: deb_path: %s", __FUNCTION__, deb_path);
-
-  /* Create NSIS installer. */
-
-  if (mkdtemp (exe_dir) == NULL)
-    {
-      g_free (rpm_path);
-      g_free (deb_path);
-      goto rm_rpm_exit;
-    }
-  exe_path = g_build_filename (exe_dir, "p.nsis", NULL);
-  g_debug ("%s: exe_path: %s", __FUNCTION__, exe_path);
-  if (lsc_user_exe_create (name, password, exe_path))
-    {
-      g_free (rpm_path);
-      g_free (deb_path);
-      g_free (exe_path);
-      goto rm_exit;
-    }
-  g_debug ("%s: exe_path: %s", __FUNCTION__, exe_path);
-
-  /* Read the packages and key into memory. */
-
-  error = NULL;
-  g_file_get_contents (public_key_path, public_key, &length, &error);
-  if (error)
-    {
-      g_free (rpm_path);
-      g_free (deb_path);
-      g_free (exe_path);
-      g_error_free (error);
-      goto rm_exit;
-    }
-
-  error = NULL;
-  g_file_get_contents (private_key_path, private_key, &length, &error);
-  if (error)
-    {
-      g_free (rpm_path);
-      g_free (deb_path);
-      g_free (exe_path);
-      g_error_free (error);
-      goto rm_exit;
-    }
-
-  error = NULL;
-  g_file_get_contents (rpm_path, (gchar **) rpm, rpm_size, &error);
-  g_free (rpm_path);
-  if (error)
-    {
-      g_error_free (error);
-      g_free (deb_path);
-      g_free (exe_path);
-      goto rm_exit;
-    }
-
-  error = NULL;
-  g_file_get_contents (deb_path, (gchar **) deb, deb_size, &error);
-  g_free (deb_path);
-  if (error)
-    {
-      g_error_free (error);
-      g_free (exe_path);
-      goto rm_exit;
-    }
-
-  error = NULL;
-  g_file_get_contents (exe_path, (gchar **) exe, exe_size, &error);
-  g_free (exe_path);
-  if (error)
-    {
-      g_error_free (error);
-      goto rm_exit;
-    }
-
-  /* Return. */
-
-  ret = 0;
-
- rm_exit:
-
-  file_utils_rmdir_rf (exe_dir);
-
- rm_rpm_exit:
-
-  file_utils_rmdir_rf (rpm_dir);
-
- free_exit:
-
-  g_free (public_key_path);
-  g_free (private_key_path);
-
- rm_key_exit:
-
-  file_utils_rmdir_rf (key_dir);
-
-  return ret;
-}
