@@ -50,7 +50,7 @@ typedef struct
 } name_value_t;
 
 int
-init_manage (GSList*, int, const gchar*, int, int, int, void (*) ());
+init_manage (GSList*, int, const gchar*, int, int, int, void (*) (), int);
 
 int
 init_manage_helper (GSList *, const gchar *, int, void (*) ());
@@ -283,6 +283,9 @@ get_iterator_owner (iterator_t*);
 
 /* Resources. */
 
+int
+resource_name (const char *, const char *, int, char **);
+
 int
 resource_count (const char *, const get_data_t *);
 
@@ -355,7 +358,10 @@ typedef enum
   ALERT_METHOD_HTTP_GET,
   ALERT_METHOD_SOURCEFIRE,
   ALERT_METHOD_SYSLOG,
-  ALERT_METHOD_VERINICE
+  ALERT_METHOD_VERINICE,
+  ALERT_METHOD_SEND,
+  ALERT_METHOD_SCP,
+  ALERT_METHOD_SNMP
 } alert_method_t;
 
 /**
@@ -366,7 +372,9 @@ typedef enum
   ALERT_CONDITION_ERROR,
   ALERT_CONDITION_ALWAYS,
   ALERT_CONDITION_SEVERITY_AT_LEAST,
-  ALERT_CONDITION_SEVERITY_CHANGED
+  ALERT_CONDITION_SEVERITY_CHANGED,
+  ALERT_CONDITION_FILTER_COUNT_AT_LEAST,
+  ALERT_CONDITION_FILTER_COUNT_CHANGED
 } alert_condition_t;
 
 int
@@ -628,6 +636,9 @@ task_run_status (task_t);
 void
 set_task_run_status (task_t, task_status_t);
 
+int
+task_result_count (task_t, int);
+
 report_t
 task_running_report (task_t);
 
@@ -661,6 +672,12 @@ set_task_groups (task_t, array_t*, gchar**);
 int
 set_task_schedule (task_t, schedule_t, int);
 
+int
+set_task_schedule_periods (const gchar *, int);
+
+int
+set_task_schedule_periods_id (task_t, int);
+
 unsigned int
 task_report_count (task_t);
 
@@ -1111,6 +1128,9 @@ set_scan_host_start_time (report_t, const char*, const char*);
 void
 set_scan_host_start_time_otp (report_t, const char*, const char*);
 
+int
+scan_host_end_time (report_t, const char*);
+
 void
 set_scan_host_end_time (report_t, const char*, const char*);
 
@@ -1337,6 +1357,9 @@ target_count (const get_data_t *);
 void
 init_user_target_iterator (iterator_t*, target_t);
 
+void
+init_target_iterator_one (iterator_t*, target_t);
+
 int
 init_target_iterator (iterator_t*, const get_data_t *);
 
@@ -1451,6 +1474,9 @@ target_task_iterator_name (iterator_t*);
 const char*
 target_task_iterator_uuid (iterator_t*);
 
+int
+target_task_iterator_readable (iterator_t*);
+
 
 /* Configs. */
 
@@ -1465,6 +1491,7 @@ typedef struct
   char *nvt_name;  ///< Name of NVT preference affects.
   char *nvt_oid;   ///< OID of NVT preference affects.
   array_t *alts;   ///< Array of gchar's.  Alternate values for radio type.
+  char *default_value; ///< Default value of preference.
 } preference_t;
 
 /**
@@ -1480,7 +1507,7 @@ typedef struct
 
 int
 create_config (const char*, const char*, const array_t*, const array_t*,
-               config_t*, char**);
+               const char*, config_t*, char**);
 
 int
 create_config_from_scanner (const char*, const char *, const char *,
@@ -1798,7 +1825,7 @@ get_nvti_xml (iterator_t*, int, int, int, const char*, config_t, int);
 char*
 task_preference_value (task_t, const char *);
 
-void
+int
 set_task_preferences (task_t, array_t *);
 
 void
@@ -2986,6 +3013,7 @@ modify_role (const char *, const char *, const char *, const char *);
  */
 typedef enum
 {
+  KEYWORD_TYPE_UNKNOWN,
   KEYWORD_TYPE_INTEGER,
   KEYWORD_TYPE_DOUBLE,
   KEYWORD_TYPE_STRING
@@ -3354,6 +3382,9 @@ setting_filter (const char *);
 const char *
 setting_severity ();
 
+double
+setting_default_severity_dbl ();
+
 int
 setting_dynamic_severity_int ();
 
