@@ -1082,6 +1082,10 @@ where_owned_user (const char *user_id, const char *user_sql, const char *type,
                                 user_sql,
                                 user_sql,
                                 permission_or->str);
+
+          if ((strcmp (type, "report") == 0)
+              || (strcmp (type, "result") == 0))
+            g_free (clause);
           else
             permission_clause = clause;
         }
@@ -1276,6 +1280,8 @@ where_owned_user (const char *user_id, const char *user_sql, const char *type,
                             user_sql,
                             permission_clause ? permission_clause : "");
 
+      g_free (permission_clause);
+
       if (get->trash && (strcasecmp (type, "task") == 0))
         {
           gchar *new;
