@@ -43,7 +43,8 @@ manage_session_init (const char *uuid)
        " (id SERIAL PRIMARY KEY,"
        "  uuid text UNIQUE NOT NULL);");
   sql ("DELETE FROM current_credentials;");
-  sql ("INSERT INTO current_credentials (uuid) VALUES ('%s');", uuid);
+  if (uuid)
+    sql ("INSERT INTO current_credentials (uuid) VALUES ('%s');", uuid);
 }
 
 
@@ -830,6 +831,18 @@ manage_create_sql_functions ()
            "  ORDER BY coalesce (owner, 0) DESC LIMIT 1;"
            "$$ LANGUAGE SQL;");
 
+      sql ("CREATE OR REPLACE FUNCTION current_severity (real, text)"
+           " RETURNS double precision AS $$"
+           "  SELECT coalesce ((CASE WHEN $1 > " G_STRINGIFY (SEVERITY_LOG)
+           "                    THEN (SELECT CAST (cvss_base"
+           "                                       AS double precision)"
+           "                          FROM nvts"
+           "                          WHERE nvts.oid = $2)"
+           "                    ELSE $1"
+           "                    END),"
+           "                   $1);"
+           "$$ LANGUAGE SQL;");
+
 #define OVERRIDES_SQL(severity_sql)                         \
  " coalesce"                                                \
  "  ((SELECT overrides.new_severity"                        \
@@ -885,15 +898,8 @@ manage_create_sql_functions ()
            /*        Dynamic severity, overrides on. */
            "         THEN (SELECT max"
            "                       (" OVERRIDES_SQL
-                                       ("CASE"
-                                        " WHEN results.severity"
-                                        "      > " G_STRINGIFY (SEVERITY_LOG)
-                                        " THEN coalesce"
-                                        "       ((SELECT CAST (cvss_base AS REAL)"
-                                        "         FROM nvts"
-                                        "         WHERE nvts.oid = results.nvt),"
-                                        "        results.severity)"
-                                        " ELSE results.severity END") ")"
+                                       ("current_severity (results.severity,"
+                                        "                  results.nvt)") ")"
            "               FROM results"
            "               WHERE results.report = $1"
            "                 AND results.qod >= $3)"
@@ -902,18 +908,8 @@ manage_create_sql_functions ()
            "         THEN (SELECT max (CASE"
            "                           WHEN results.type IS NULL"
            "                           THEN 0::real"
-           "                           ELSE (CASE"
-           "                                 WHEN results.severity"
-           "                                      > " G_STRINGIFY (SEVERITY_LOG)
-           "                                 THEN coalesce"
-           "                                       ((SELECT CAST (cvss_base"
-           "                                                      AS REAL)"
-           "                                         FROM nvts"
-           "                                         WHERE nvts.oid"
-           "                                               = results.nvt),"
-           "                                        results.severity)"
-           "                                 ELSE results.severity"
-           "                                 END)"
+           "                           ELSE current_severity"
+           "                                 (results.severity, results.nvt)"
            "                           END)"
            "               FROM results"
            "               WHERE results.report = $1"
@@ -975,15 +971,8 @@ manage_create_sql_functions ()
            "               WHERE results.report = $1"
            "               AND results.qod >= $3"
            "               AND (" OVERRIDES_SQL
-                                   ("CASE"
-                                    " WHEN results.severity"
-                                    "      > " G_STRINGIFY (SEVERITY_LOG)
-                                    " THEN coalesce"
-                                    "       ((SELECT CAST (cvss_base AS REAL)"
-                                    "         FROM nvts"
-                                    "         WHERE nvts.oid = results.nvt),"
-                                    "        results.severity)"
-                                    " ELSE results.severity END")
+                                   ("current_severity (results.severity,"
+                                    "                  results.nvt)")
            "                    BETWEEN level_min_severity"
            "                             ($4, severity_class ())"
            "                            AND level_max_severity"
@@ -997,16 +986,8 @@ manage_create_sql_functions ()
            "               AND ((CASE"
            "                     WHEN results.type IS NULL"
            "                     THEN 0::real"
-           "                     ELSE (CASE"
-           "                           WHEN results.severity"
-           "                                > " G_STRINGIFY (SEVERITY_LOG)
-           "                           THEN coalesce"
-           "                                 ((SELECT CAST (cvss_base AS REAL)"
-           "                                   FROM nvts"
-           "                                   WHERE nvts.oid = results.nvt),"
-           "                                  results.severity)"
-           "                           ELSE results.severity"
-           "                           END)"
+           "                     ELSE current_severity (results.severity,"
+           "                                            results.nvt)"
            "                     END)"
            "                    BETWEEN level_min_severity ($4, severity_class ())"
            "                            AND level_max_severity"
@@ -1065,16 +1046,9 @@ manage_create_sql_functions ()
            "         THEN (SELECT"
            "                round"
            "                 (max (" OVERRIDES_SQL
-                                      ("CASE"
-                                       " WHEN results.severity"
-                                       "      > " G_STRINGIFY (SEVERITY_LOG)
-                                       " THEN coalesce"
-                                       "       ((SELECT CAST (cvss_base"
-                                       "                      AS REAL)"
-                                       "         FROM nvts"
-                                       "         WHERE nvts.oid = results.nvt),"
-                                       "        results.severity)"
-                                       " ELSE results.severity END") ")::numeric,"
+                                      ("current_severity"
+                                       " (results.severity,"
+                                       "  results.nvt)") ")::numeric,"
            "                  2)"
            "               FROM results"
            "               WHERE results.report = (SELECT id FROM reports"
@@ -1085,17 +1059,9 @@ manage_create_sql_functions ()
            "                 AND results.qod >= $3)"
            "         WHEN dynamic_severity ()"
            /*        Dynamic severity, overrides off. */
-           "         THEN (SELECT round (max (CASE"
-           "                                  WHEN results.severity"
-           "                                       > " G_STRINGIFY (SEVERITY_LOG)
-           "                                  THEN coalesce"
-           "                                        ((SELECT CAST (cvss_base"
-           "                                                       AS REAL)"
-           "                                          FROM nvts"
-           "                                          WHERE nvts.oid"
-           "                                                = results.nvt),"
-           "                                         results.severity)"
-           "                                  ELSE results.severity END)::numeric,"
+           "         THEN (SELECT round (max (current_severity"
+           "                                   (results.severity,"
+           "                                    results.nvt))::numeric,"
            "                             2)"
            "               FROM results"
            "               WHERE results.report = (SELECT id FROM reports"
@@ -2210,23 +2176,13 @@ create_tables ()
        "                   WHERE result = results.id"
        "                     AND result_overrides.user = users.id"
        "                     AND severity_matches_ov"
-       "                           (coalesce"
-       "                             ((SELECT CAST (cvss_base"
-       "                                            AS double precision)"
-       "                               FROM nvts"
-       "                               WHERE nvts.oid = results.nvt),"
-       "                              results.severity),"
+       "                           (current_severity (results.severity,"
+       "                                              results.nvt),"
        "                            ov_old_severity)"
        "                   LIMIT 1),"
-       "                   coalesce ((SELECT CAST (cvss_base AS double precision)"
-       "                              FROM nvts"
-       "                              WHERE nvts.oid = results.nvt),"
-       "                             results.severity))"
+       "                  current_severity (results.severity, results.nvt))"
        "      ELSE"
-       "        coalesce ((SELECT CAST (cvss_base AS double precision)"
-       "                   FROM nvts"
-       "                   WHERE nvts.oid = results.nvt),"
-       "                  results.severity)"
+       "        current_severity (results.severity, results.nvt)"
        "      END"
        "    ELSE"
        "      CASE WHEN override != 0 THEN"
