@@ -273,8 +273,6 @@ void set_task_schedule_next_time (task_t, time_t);
 
 void set_task_schedule_next_time_uuid (const gchar *, time_t);
 
-int set_task_schedule_periods (const gchar *, int);
-
 void init_otp_pref_iterator (iterator_t *, config_t, const char *);
 const char *otp_pref_iterator_name (iterator_t *);
 const char *otp_pref_iterator_value (iterator_t *);
@@ -330,7 +328,7 @@ void update_duration_schedule_periods (task_t);
 
 void reinit_manage_process ();
 
-void manage_update_nvti_cache ();
+int manage_update_nvti_cache ();
 
 int manage_report_host_details (report_t, const char *, entity_t);
 
@@ -350,4 +348,8 @@ int valid_omp_command (const char *);
 
 void check_generate_scripts ();
 
+void auto_delete_reports ();
+
+void set_report_scheduled (report_t);
+
 #endif /* not OPENVAS_MANAGER_MANAGE_SQL_H */
