@@ -87,7 +87,8 @@ manage_session_init (const char *uuid)
        " (id INTEGER PRIMARY KEY,"
        "  uuid text UNIQUE NOT NULL);");
   sql ("DELETE FROM current_credentials;");
-  sql ("INSERT INTO current_credentials (uuid) VALUES ('%s');", uuid);
+  if (uuid)
+    sql ("INSERT INTO current_credentials (uuid) VALUES ('%s');", uuid);
 }
 
 
@@ -2343,6 +2344,8 @@ create_tables ()
        " ON results (report, host);");
   sql ("CREATE INDEX IF NOT EXISTS results_by_task"
        " ON results (task);");
+  sql ("CREATE INDEX IF NOT EXISTS results_by_task_qod_severity"
+       " ON results (task, qod, severity);");
   sql ("CREATE INDEX IF NOT EXISTS results_by_type"
        " ON results (type);");
   sql ("CREATE TABLE IF NOT EXISTS roles"
@@ -2436,6 +2439,7 @@ create_tables ()
 
   owned_clause = where_owned_for_get ("override", "users.id");
 
+  sql_begin_exclusive ();
   sql ("DROP VIEW IF EXISTS result_overrides;");
   sql ("CREATE VIEW result_overrides AS"
        " SELECT users.id AS user,"
@@ -2465,9 +2469,11 @@ create_tables ()
        " overrides.port DESC, overrides.severity ASC,"
        " overrides.creation_time DESC",
        owned_clause);
+  sql ("COMMIT;");
 
   g_free (owned_clause);
 
+  sql_begin_exclusive ();
   sql ("DROP VIEW IF EXISTS result_new_severities;");
   sql ("CREATE VIEW result_new_severities AS"
        "  SELECT results.id as result, users.id as user, dynamic, override,"
@@ -2477,16 +2483,32 @@ create_tables ()
        "                   WHERE result = results.id"
        "                     AND result_overrides.user = users.id"
        "                     AND severity_matches_ov"
-       "                           (coalesce ((SELECT cvss_base FROM nvts"
-       "                                       WHERE nvts.oid = results.nvt),"
+       "                           (coalesce ((CASE WHEN results.severity"
+       "                                                 > " G_STRINGIFY
+                                                              (SEVERITY_LOG)
+       "                                       THEN (SELECT cvss_base"
+       "                                             FROM nvts"
+       "                                             WHERE nvts.oid = results.nvt)"
+       "                                       ELSE results.severity"
+       "                                       END),"
        "                                      results.severity),"
        "                            ov_old_severity)),"
-       "                  coalesce ((SELECT cvss_base FROM nvts"
-       "                             WHERE nvts.oid = results.nvt),"
+       "                  coalesce ((CASE WHEN results.severity"
+       "                                       > " G_STRINGIFY (SEVERITY_LOG)
+       "                             THEN (SELECT cvss_base"
+       "                                   FROM nvts"
+       "                                   WHERE nvts.oid = results.nvt)"
+       "                             ELSE results.severity"
+       "                             END),"
        "                            results.severity))"
        "      ELSE"
-       "        coalesce ((SELECT cvss_base FROM nvts"
-       "                   WHERE nvts.oid = results.nvt),"
+       "        coalesce ((CASE WHEN results.severity"
+       "                             > " G_STRINGIFY (SEVERITY_LOG)
+       "                   THEN (SELECT cvss_base"
+       "                         FROM nvts"
+       "                         WHERE nvts.oid = results.nvt)"
+       "                   ELSE results.severity"
+       "                   END),"
        "                  results.severity)"
        "      END"
        "    ELSE"
@@ -2505,7 +2527,9 @@ create_tables ()
        "  FROM results, users"
        "  JOIN (SELECT 0 AS override UNION SELECT 1 AS override_opts)"
        "  JOIN (SELECT 0 AS dynamic UNION SELECT 1 AS dynamic_opts);");
+  sql ("COMMIT;");
 
+  sql_begin_exclusive ();
   sql ("DROP VIEW IF EXISTS results_autofp;");
   sql ("CREATE VIEW results_autofp AS"
        " SELECT results.id as result, autofp_selection,"
@@ -2568,6 +2592,7 @@ create_tables ()
        "  (SELECT 0 AS autofp_selection"
        "   UNION SELECT 1 AS autofp_selection"
        "   UNION SELECT 2 AS autofp_selection) AS autofp_opts;");
+  sql ("COMMIT;");
 }
 
 
@@ -2693,41 +2718,76 @@ manage_scap_loaded ()
  * @brief Backup the database to a file.
  *
  * @param[in]   database     Database to backup.
- * @param[out]  backup_file  Freshly allocated name of backup file.
+ * @param[out]  backup_file  Location for freshly allocated name of backup
+ *                           file, or NULL.  Only set on success.
  *
  * @return 0 success, -1 error.
  */
 static int
-backup_db (const gchar *database, gchar **backup_file)
+backup_db (const gchar *database, gchar **backup_file_arg)
 {
-  gchar *command;
-  int ret;
+  gchar *backup_file;
+  sqlite3 *backup_db, *actual_task_db;
+  sqlite3_backup *backup;
 
-  sql_begin_exclusive ();
+  backup_file = g_strdup_printf ("%s.bak", database);
 
-  command = g_strdup_printf ("cp %s %s.bak > /dev/null 2>&1"
-                             "&& for f in `ls %s-* 2> /dev/null | grep --invert .\\*bak`;"
-                             "   do cp $f $f.bak > /dev/null 2>&1;"
-                             "   done",
-                             database,
-                             database,
-                             database);
-  tracef ("   command: %s\n", command);
-  ret = system (command);
-  g_free (command);
-
-  if (ret == -1 || WEXITSTATUS (ret))
+  if (sqlite3_open (backup_file, &backup_db) != SQLITE_OK)
     {
-      sql ("ROLLBACK;");
-      return -1;
+      g_warning ("%s: sqlite3_open failed: %s\n",
+                 __FUNCTION__,
+                 sqlite3_errmsg (task_db));
+      goto fail;
     }
 
-  sql ("COMMIT;");
+  /* Turn off WAL for the backup db. */
+  actual_task_db = task_db;
+  task_db = backup_db;
+  sql ("PRAGMA journal_mode=DELETE;");
+  task_db = actual_task_db;
 
-  if (backup_file)
-    *backup_file = g_strdup_printf ("%s.bak", database);
+  backup = sqlite3_backup_init (backup_db, "main", task_db, "main");
+  if (backup == NULL)
+    {
+      g_warning ("%s: sqlite3_backup_init failed: %s\n",
+                 __FUNCTION__,
+                 sqlite3_errmsg (backup_db));
+      goto fail;
+    }
 
+  while (1)
+    {
+      int ret;
+
+      ret = sqlite3_backup_step (backup, 20 /* pages */);
+      if (ret == SQLITE_DONE)
+        break;
+      if (ret == SQLITE_OK)
+        continue;
+      if (ret == SQLITE_BUSY || ret == SQLITE_LOCKED)
+        {
+          sqlite3_sleep (250);
+          continue;
+        }
+      g_warning ("%s: sqlite3_backup_step failed: %s\n",
+                 __FUNCTION__,
+                 sqlite3_errstr (ret));
+      sqlite3_backup_finish (backup);
+      goto fail;
+    }
+  sqlite3_backup_finish (backup);
+  sqlite3_close (backup_db);
+
+  if (backup_file_arg)
+    *backup_file_arg = backup_file;
+  else
+    g_free (backup_file);
   return 0;
+
+ fail:
+  sqlite3_close (backup_db);
+  g_free (backup_file);
+  return -1;
 }
 
 /**
