@@ -269,6 +269,11 @@ gboolean disable_encrypted_credentials;
  */
 gboolean scheduling_enabled;
 
+/**
+ * @brief The OMP client's address.
+ */
+char client_address[INET6_ADDRSTRLEN];
+
 
 /* Forking, serving the client. */
 
@@ -348,13 +353,12 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
 {
   /* Accept the client connection. */
   pid_t pid;
-  struct sockaddr_in client_address;
-  socklen_t size = sizeof (client_address);
   int client_socket;
-  client_address.sin_family = AF_INET;
-  while ((client_socket = accept (server_socket,
-                                  (struct sockaddr *) &client_address,
-                                  &size))
+  struct sockaddr_storage addr;
+  socklen_t addrlen = sizeof (addr);
+
+  while ((client_socket = accept (server_socket, (struct sockaddr *) &addr,
+                                  &addrlen))
          == -1)
     {
       if (errno == EINTR)
@@ -367,6 +371,7 @@ accept_and_maybe_fork (int server_socket, sigset_t *sigmask_current)
                   strerror (errno));
       exit (EXIT_FAILURE);
     }
+  sockaddr_as_str (&addr, client_address);
 
   /* Fork a child to serve the client. */
   pid = fork ();
@@ -736,7 +741,12 @@ void
 handle_sigsegv (/*@unused@*/ int given_signal)
 {
   manage_cleanup_process_error (given_signal);
-  cleanup ();
+
+  /* This previously called "cleanup", but it seems that the regular manager
+   * code runs again before the default handler is invoked, at least when the
+   * SIGKILL is sent from the command line.  This was leading to errors which
+   * were preventing the default handler from running and dumping core. */
+
   /* Raise signal again, to exit with the correct return value. */
   setup_signal_handler (given_signal, SIG_DFL, 0);
   raise (given_signal);
@@ -790,14 +800,16 @@ handle_sigabrt_simple (int signal)
  *                                     (1) or rebuilt (0).
  * @param[in]  register_cleanup        Whether to register cleanup with atexit.
  * @param[in]  progress                Function to update progress, or NULL.
+ * @param[in]  skip_create_tables      Whether to skip table creation.
  *
  * @return If this function did not exit itself, returns exit code.
  */
 static int
 update_or_rebuild_nvt_cache (int update_nvt_cache, int register_cleanup,
-                             void (*progress) ())
+                             void (*progress) (), int skip_create_tables)
 {
   int ret;
+
   /* Initialise OMP daemon. */
 
   if (update_nvt_cache == 0)
@@ -817,7 +829,8 @@ update_or_rebuild_nvt_cache (int update_nvt_cache, int register_cleanup,
                      manage_max_hosts (),
                      0, /* Max email attachment size. */
                      0, /* Max email include size. */
-                     progress))
+                     progress,
+                     skip_create_tables))
     {
       case 0:
         break;
@@ -884,12 +897,13 @@ update_or_rebuild_nvt_cache (int update_nvt_cache, int register_cleanup,
  *                                     (1) or rebuilt (0).
  * @param[in]  register_cleanup        Whether to register cleanup with atexit.
  * @param[in]  progress                Function to update progress, or NULL.
+ * @param[in]  skip_create_tables      Whether to skip table creation.
  *
  * @return Exit status of child spawned to do rebuild.
  */
 static int
 rebuild_nvt_cache_retry (int update_or_rebuild, int register_cleanup,
-                         void (*progress) ())
+                         void (*progress) (), int skip_create_tables)
 {
   proctitle_set ("openvasmd: Reloading");
   infof ("%s: Reloading NVT cache\n", __FUNCTION__);
@@ -917,7 +931,8 @@ rebuild_nvt_cache_retry (int update_or_rebuild, int register_cleanup,
         {
           /* Child: Try reload. */
           int ret = update_or_rebuild_nvt_cache (update_or_rebuild,
-                                                 register_cleanup, progress);
+                                                 register_cleanup, progress,
+                                                 skip_create_tables);
 
           exit (ret);
         }
@@ -953,7 +968,7 @@ fork_update_nvt_cache ()
 
         infof ("   internal NVT cache update\n");
 
-        rebuild_nvt_cache_retry (0, 0, NULL);
+        rebuild_nvt_cache_retry (0, 0, NULL, 1);
 
         /* Exit. */
 
@@ -1334,7 +1349,7 @@ main (int argc, char** argv)
           G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE,
           &decrypt_all_credentials, NULL, NULL },
         { "new-password", '\0', 0, G_OPTION_ARG_STRING, &new_password, "Modify user's password and exit.", "<password>" },
-        { "optimize", '\0', 0, G_OPTION_ARG_STRING, &optimize, "Run an optimization: vacuum, analyze, cleanup-config-prefs, remove-open-port-results, cleanup-port-names, rebuild-report-cache or update-report-cache.", "<name>" },
+        { "optimize", '\0', 0, G_OPTION_ARG_STRING, &optimize, "Run an optimization: vacuum, analyze, cleanup-config-prefs, remove-open-port-results, cleanup-port-names, cleanup-result-severities, rebuild-report-cache or update-report-cache.", "<name>" },
         { "port", 'p', 0, G_OPTION_ARG_STRING, &manager_port_string, "Use port number <number>.", "<number>" },
         { "port2", '\0', 0, G_OPTION_ARG_STRING, &manager_port_string_2, "Use port number <number> for address 2.", "<number>" },
         { "progress", '\0', 0, G_OPTION_ARG_NONE, &progress, "Display progress during --rebuild and --update.", NULL },
@@ -1965,7 +1980,8 @@ main (int argc, char** argv)
           fflush (stdout);
         }
       ret = rebuild_nvt_cache_retry (update_nvt_cache, 1,
-                                     progress ? spin_progress : NULL);
+                                     progress ? spin_progress : NULL,
+                                     0);
       if (progress)
         {
           putchar ('\b');
@@ -2008,7 +2024,8 @@ main (int argc, char** argv)
   /* Initialise OMP daemon. */
 
   switch (init_ompd (log_config, 0, database, max_ips_per_target,
-                     max_email_attachment_size, max_email_include_size, NULL))
+                     max_email_attachment_size, max_email_include_size, NULL,
+                     0))
     {
       case 0:
         break;
