@@ -44,6 +44,7 @@
 
 #include "otp.h"
 #include "manage.h"
+#include "scanner.h"
 #include "manage_sql.h"
 #include "tracef.h"
 #include "types.h"
@@ -446,7 +447,7 @@ set_scanner_init_state (scanner_init_state_t state)
 
 /** @todo As with the OMP version, these should most likely be passed to and
  *        from the client in a data structure like an otp_parser_t. */
-extern char from_scanner[];
+extern char *from_scanner;
 extern buffer_size_t from_scanner_start;
 extern buffer_size_t from_scanner_end;
 
@@ -467,19 +468,9 @@ sync_buffer ()
     }
   else if (from_scanner_start == 0)
     {
-      if (from_scanner_end == from_buffer_size)
+      if (openvas_scanner_full () && openvas_scanner_realloc ())
         {
-          /** @todo If the buffer is entirely full here then exit.
-           *     (Or will hang waiting for buffer to empty.)
-           *     Could happen if scanner sends a field longer than the buffer.
-           *         Could realloc buffer instead.
-           *             which may eventually use all mem and bring down manager
-           *                 would only bring down process serving the client
-           *                 may lead to out of mem in other processes?
-           *                 could realloc to an upper limit within avail mem
-           *         Could process some OTP to empty space in the buffer.
-           **/
-          tracef ("   scanner buffer full\n");
+          g_warning ("From scanner buffer treshold.");
           return -1;
         }
     }
@@ -918,6 +909,14 @@ process_otp_scanner_input (void (*progress) ())
              != NULL))
     {
       assert (match >= input);
+
+      /* Check whether we've had a transaction open too long, because
+       * it may take some time until we get out of this loop and do a
+       * process_omp_change, and we don't want to hold up other writer
+       * processes.  Note that in GSA even tabular pages like Tasks now
+       * write (settings) to the db. */
+      manage_transaction_stop (FALSE);
+
       if ((((match - input) + from_start + 1) < from_end)
           && (match[1] == '|')
           && (match[2] == '>'))
