@@ -176,6 +176,10 @@ sql_open (const char *database)
       return -1;
     }
 
+  g_debug ("   %s: db open, max retry sleep time is %i\n",
+           __FUNCTION__,
+           OPENVAS_SQLITE_SLEEP_MAX);
+
   sqlite3_file_control (task_db, NULL, SQLITE_FCNTL_CHUNK_SIZE, &chunk_size);
   return 0;
 }
@@ -279,14 +283,15 @@ sql_prepare_internal (int retry, int log, const char* sql, va_list args,
   sqlite_stmt = NULL;
   while (1)
     {
-      ret = sqlite3_prepare (task_db, (char*) formatted, -1, &sqlite_stmt,
-                             &tail);
+      ret = sqlite3_prepare_v2 (task_db, (char*) formatted, -1, &sqlite_stmt,
+                                &tail);
       if (ret == SQLITE_BUSY || ret == SQLITE_LOCKED)
         {
           if (retry)
             {
-              if (retries > 10)
-                openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+              if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+                openvas_usleep (MIN ((retries - 10) * 10000,
+                                     OPENVAS_SQLITE_SLEEP_MAX));
               retries++;
               continue;
             }
@@ -341,8 +346,9 @@ sql_exec_internal (int retry, sql_stmt_t *stmt)
         {
           if (retry)
             {
-              if (retries > 10)
-                openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+              if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+                openvas_usleep (MIN ((retries - 10) * 10000,
+                                     OPENVAS_SQLITE_SLEEP_MAX));
               retries++;
               continue;
             }
@@ -352,35 +358,12 @@ sql_exec_internal (int retry, sql_stmt_t *stmt)
         }
       if (ret == SQLITE_DONE)
         return 0;
-      if (ret == SQLITE_ERROR || ret == SQLITE_MISUSE)
-        {
-          if (ret == SQLITE_ERROR)
-            {
-              ret = sqlite3_reset (stmt->stmt);
-              if (ret == SQLITE_BUSY || ret == SQLITE_LOCKED)
-                {
-                  if (retry)
-                    {
-                      if (retries > 10)
-                        openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
-                      retries++;
-                      continue;
-                    }
-                  if (retries++ < 10)
-                    continue;
-                  return -2;
-                }
-              if (ret == SQLITE_SCHEMA)
-                /* Schema has changed, caller must rerun prepare. */
-                return 2;
-            }
-          g_warning ("%s: sqlite3_step failed: %s\n",
-                     __FUNCTION__,
-                     sqlite3_errmsg (task_db));
-          return -1;
-        }
-      assert (ret == SQLITE_ROW);
-      return 1;
+      if (ret == SQLITE_ROW)
+        return 1;
+      g_warning ("%s: sqlite3_step failed: %s\n",
+                 __FUNCTION__,
+                 sqlite3_errmsg (task_db));
+      return -1;
     }
 }
 
@@ -465,6 +448,17 @@ sql_begin_immediate ()
   sql ("BEGIN IMMEDIATE;");
 }
 
+/**
+ * @brief Begin an exclusive transaction.
+ *
+ * @return 0 got lock, 1 gave up, -1 error.
+ */
+int
+sql_begin_immediate_giveup ()
+{
+  return sql_giveup ("BEGIN IMMEDIATE;");
+}
+
 
 /* Iterators. */
 
@@ -541,8 +535,9 @@ sql_bind_blob (sql_stmt_t *stmt, int position, const void *value,
                                SQLITE_TRANSIENT);
       if (ret == SQLITE_BUSY)
         {
-          if (retries > 10)
-            openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+          if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+            openvas_usleep (MIN ((retries - 10) * 10000,
+                                 OPENVAS_SQLITE_SLEEP_MAX));
           retries++;
           continue;
         }
@@ -575,8 +570,9 @@ sql_bind_int64 (sql_stmt_t *stmt, int position, long long int *value)
       ret = sqlite3_bind_int64 (stmt->stmt, position, *value);
       if (ret == SQLITE_BUSY)
         {
-          if (retries > 10)
-            openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+          if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+            openvas_usleep (MIN ((retries - 10) * 10000,
+                                 OPENVAS_SQLITE_SLEEP_MAX));
           retries++;
           continue;
         }
@@ -609,8 +605,9 @@ sql_bind_double (sql_stmt_t *stmt, int position, double *value)
       ret = sqlite3_bind_double (stmt->stmt, position, *value);
       if (ret == SQLITE_BUSY)
         {
-          if (retries > 10)
-            openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+          if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+            openvas_usleep (MIN ((retries - 10) * 10000,
+                                 OPENVAS_SQLITE_SLEEP_MAX));
           retries++;
           continue;
         }
@@ -649,8 +646,9 @@ sql_bind_text (sql_stmt_t *stmt, int position, const gchar *value,
                                SQLITE_TRANSIENT);
       if (ret == SQLITE_BUSY)
         {
-          if (retries > 10)
-            openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+          if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+            openvas_usleep (MIN ((retries - 10) * 10000,
+                                 OPENVAS_SQLITE_SLEEP_MAX));
           retries++;
           continue;
         }
@@ -695,8 +693,9 @@ sql_reset (sql_stmt_t *stmt)
       ret = sqlite3_reset (stmt->stmt);
       if (ret == SQLITE_BUSY)
         {
-          if (retries > 10)
-            openvas_usleep (MIN ((retries - 10) * 10000, 5000000));
+          if ((retries > 10) && (OPENVAS_SQLITE_SLEEP_MAX > 0))
+            openvas_usleep (MIN ((retries - 10) * 10000,
+                                 OPENVAS_SQLITE_SLEEP_MAX));
           retries++;
           continue;
         }
